@@ -2,9 +2,9 @@
 APPLICATION_NAME = "DSO Tool"
 REGEX_PATTERNS = {
     'stage' : r"^([a-zA-Z][a-zA-Z0-9]+)/?([0-9])?$",
-    'parameter_key': r"^[a-zA-Z][.a-zA-Z0-9_-]*[a-zA-Z0-9_-]$",
-    'secret_key': r"^[a-zA-Z][.a-zA-Z0-9_-]*[a-zA-ZA-Z0-9_-]$",
-    'template_key': r"^[a-zA-Z][./a-zA-Z0-9_-]*[a-zA-Z0-9_-]$",
+    'parameter_key': r"^[a-zA-Z][.a-zA-Z0-9_-]*[a-zA-Z0-9]$",
+    'secret_key': r"^[a-zA-Z][.a-zA-Z0-9_-]*[a-zA-ZA-Z0-9]$",
+    'template_key': r"^[a-zA-Z][./a-zA-Z0-9_-]*[a-zA-Z0-9]$",
 }
 
 MESSAGES = {
