@@ -1,15 +1,15 @@
 import re
 import boto3
-from mabledsocli.exceptions import DSOException
-from mabledsocli.logger import Logger
-from mabledsocli.config import Configs
-from mabledsocli.providers import Providers
-from mabledsocli.parameters import ParameterProvider
-from mabledsocli.stages import Stages
-from mabledsocli.constants import *
-from mabledsocli.dict_utils import set_dict_value
-from mabledsocli.contexts import Contexts
-from mabledsocli.aws_utils import *
+from dsocli.exceptions import DSOException
+from dsocli.logger import Logger
+from dsocli.config import Configs
+from dsocli.providers import Providers
+from dsocli.parameters import ParameterProvider
+from dsocli.stages import Stages
+from dsocli.constants import *
+from dsocli.dict_utils import set_dict_value
+from dsocli.contexts import Contexts
+from dsocli.aws_utils import *
 
 
 _default_spec = {
