@@ -4,12 +4,12 @@ import yaml
 import json
 import pathlib
 import numbers
-from mabledsocli.logger import Logger
-from mabledsocli.config import Configs
-from mabledsocli.parameters import ParameterProvider
-from mabledsocli.stages import Stages
-from mabledsocli.constants import *
-from mabledsocli.utils import *
+from dsocli.logger import Logger
+from dsocli.config import Configs
+from dsocli.parameters import ParameterProvider
+from dsocli.stages import Stages
+from dsocli.constants import *
+from dsocli.utils import *
 
 defaults = {
     'format': 'yaml',
