@@ -5,13 +5,13 @@ import json
 import glob
 from pathlib import Path
 import jinja2
-from mabledsocli.logger import Logger
-from mabledsocli.config import Configs
-from mabledsocli.providers import Providers
-from mabledsocli.templates import Templates, TemplateProvider
-from mabledsocli.stages import Stages
-from mabledsocli.constants import *
-from mabledsocli.exceptions import DSOException
+from dsocli.logger import Logger
+from dsocli.config import Configs
+from dsocli.providers import Providers
+from dsocli.templates import Templates, TemplateProvider
+from dsocli.stages import Stages
+from dsocli.constants import *
+from dsocli.exceptions import DSOException
 
 
 _settings = {
