@@ -45,13 +45,13 @@ class TemplateManager():
         if '//' in key:
             raise DSOException(MESSAGES['InvalidKeyStr'].format(key, '//'))
 
-    def list(self, stage, uninherited=False):
+    def list(self, stage, uninherited=False, filter=None):
         project = Configs.project
         application = Configs.application
         provider = Providers.TemplateProvider()
         renderPaths = Configs.get_template_render_paths()
         Logger.info(f"Start listing templates: project={project}, application={application}, stage={Stages.shorten(stage)}")
-        response = provider.list(project, application, stage, uninherited)
+        response = provider.list(project, application, stage, uninherited, filter)
         for template in response['Templates']:
             key = template['Key']
             if key in renderPaths:
@@ -70,7 +70,7 @@ class TemplateManager():
         project = Configs.project
         application = Configs.application
         provider = Providers.TemplateProvider()
-        Logger.info(f"Start adding template: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}, render_path={render_path}")
+        Logger.info(f"Start adding template: project={project}, application={application}, stage={Stages.shorten(stage)}, render_path={render_path}")
         # if '..' in render_path:
         #     raise DSOException(MESSAGES['InvalidRenderPath'].format(render_path))
         # if render_path == '.' or render_path == f".{os.sep}":
@@ -102,7 +102,7 @@ class TemplateManager():
         project = Configs.project
         application = Configs.application
         provider = Providers.TemplateProvider()
-        Logger.info(f"Start getting template contents: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+        Logger.info(f"Start getting the contents of template '{key}': project={project}, application={application}, stage={Stages.shorten(stage)}")
         return provider.get(project, application, stage, key, revision)
 
     def history(self, stage, key):
@@ -110,7 +110,7 @@ class TemplateManager():
         project = Configs.project
         application = Configs.application
         provider = Providers.TemplateProvider()
-        Logger.info(f"Start getting template history: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+        Logger.info(f"Start getting the history of template '{key}': project={project}, application={application}, stage={Stages.shorten(stage)}")
         return provider.history(project, application, stage, key)
 
     def delete(self, stage, key):
@@ -118,12 +118,12 @@ class TemplateManager():
         project = Configs.project
         application = Configs.application
         provider = Providers.TemplateProvider()
-        Logger.info(f"Start deleting template: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+        Logger.info(f"Start deleting template '{key}': project={project}, application={application}, stage={Stages.shorten(stage)}")
         result = provider.delete(project, application, stage, key)
         Configs.unregister_template_custom_render_path(key)
         return result
 
-    def render(self, stage, limit=''):
+    def render(self, stage, filter=None):
         project = Configs.project
         application = Configs.application
         Logger.info(f"Start rendering templates: project={project}, application={application}, stage={Stages.shorten(stage)}")
@@ -146,7 +146,7 @@ class TemplateManager():
         merge_dicts(meta, merged)
 
         Logger.info("Loading templates...")
-        templates = self.list(stage)['Templates']
+        templates = self.list(stage, filter=filter)['Templates']
 
         jinja_env = jinja2.Environment(undefined=jinja2.StrictUndefined)
 
@@ -154,7 +154,6 @@ class TemplateManager():
         rendered = []
         for item in templates:
             key = item['Key']
-            if not key.startswith(limit): continue
 
             renderPath = item['RenderTo']
             if os.path.isdir(renderPath):
